pub struct VirtioBlockDevice {
base_addr: usize,
virtqueues: Mutex<[VirtQueue<'static>; 1]>,
capacity: RwLock<u64>,
sector_size: RwLock<u32>,
features: RwLock<u32>,
read_only: RwLock<bool>,
request_queue: Mutex<VecDeque<Box<BlockIORequest>>>,
}Fields
base_addr: usizevirtqueues: Mutex<[VirtQueue<'static>; 1]>capacity: RwLock<u64>sector_size: RwLock<u32>features: RwLock<u32>read_only: RwLock<bool>request_queue: Mutex<VecDeque<Box<BlockIORequest>>>Implementations
Sourceimpl VirtioBlockDevice
impl VirtioBlockDevice
pub fn new(base_addr: usize) -> Self
fn process_request(&self, req: &mut BlockIORequest) -> Result<(), &'static str>
Sourcefn process_requests_batch(
&self,
requests: &mut [Box<BlockIORequest>],
) -> Vec<Result<(), &'static str>>
fn process_requests_batch( &self, requests: &mut [Box<BlockIORequest>], ) -> Vec<Result<(), &'static str>>
Process multiple requests in a true batch manner All requests are submitted first, then we wait for all completions